@@ -16,7 +16,7 @@ from PIL import Image
 from bs4 import BeautifulSoup
 
 
-def covid_19_163(indicator="实时"):
+def covid_163(indicator="实时"):
     """
     网易-新冠状病毒
     https://news.163.com/special/epidemic/?spssid=93326430940df93a37229666dfbc4b96&spsw=4&spss=other&#map_block
@@ -180,7 +180,7 @@ def covid_19_163(indicator="实时"):
         return pd.DataFrame(data_info_json["scrollNews"])
 
 
-def covid_19_dxy(indicator="湖北"):
+def covid_dxy(indicator="湖北"):
     """
     20200315-丁香园接口更新分为国内和国外
     丁香园-全国统计-info
@@ -479,7 +479,7 @@ def covid_19_dxy(indicator="湖北"):
             print("请输入省/市的全称, 如: 浙江省/上海市 等")
 
 
-def covid_19_baidu(indicator="浙江"):
+def covid_baidu(indicator="湖北"):
     """
     百度-新型冠状病毒肺炎-疫情实时大数据报告
     https://voice.baidu.com/act/newpneumonia/newpneumonia/?from=osari_pc_1
@@ -623,7 +623,7 @@ def covid_19_baidu(indicator="浙江"):
         return global_country_df
 
 
-def covid_19_hist_city(city="武汉市"):
+def covid_hist_city(city="武汉市"):
     """
     疫情历史数据 城市
     https://github.com/canghailan/Wuhan-2019-nCoV
@@ -638,7 +638,7 @@ def covid_19_hist_city(city="武汉市"):
     return data_df[data_df["city"] == city]
 
 
-def covid_19_hist_province(province="湖北省"):
+def covid_hist_province(province="湖北省"):
     """
     疫情历史数据 省份
     https://github.com/canghailan/Wuhan-2019-nCoV
@@ -655,8 +655,8 @@ def covid_19_hist_province(province="湖北省"):
 
 if __name__ == "__main__":
     # 历史数据
-    epidemic_hist_city_df = covid_19_hist_city(city="武汉市")
+    epidemic_hist_city_df = covid_hist_city(city="武汉市")
     print(epidemic_hist_city_df)
-    epidemic_hist_province_df = covid_19_hist_province(province="湖北省")
+    epidemic_hist_province_df = covid_hist_province(province="湖北省")
     print(epidemic_hist_province_df)
 
